<?php
namespace Opencart\Admin\Controller\Extension\Vipodha4featurecategory\Module;
class VipodhaFeatureCategory extends \Opencart\System\Engine\Controller {
	private $error = [];

	public function install(): void {

		$this->load->model('extension/vipodha4featurecategory/module/vipodha_feature_category');
		$this->load->model('user/user_group');
		$this->load->model('setting/setting');

		//add permission
		$this->model_user_user_group->addPermission($this->user->getGroupId(), 'access', 'vipodha_feature_category');
		$this->model_user_user_group->addPermission($this->user->getGroupId(), 'modify', 'vipodha_feature_category');

		$this->model_extension_vipodha4featurecategory_module_vipodha_feature_category->install();

	}

	public function uninstall(): void {

		$this->load->model('extension/vipodha4featurecategory/module/vipodha_feature_category');
		$this->load->model('user/user_group');
		$this->load->model('setting/setting');

		// Remove permission
		$this->model_user_user_group->removePermission($this->user->getGroupId(), 'access', 'vipodha_feature_category');
		$this->model_user_user_group->removePermission($this->user->getGroupId(), 'modify', 'vipodha_feature_category');

		$this->model_extension_vipodha4featurecategory_module_vipodha_feature_category->uninstall();
	}

	public function index(): void {

		$this->load->language('extension/vipodha4featurecategory/module/vipodha_feature_category');
		$this->document->setTitle($this->language->get('heading_title'));
		$this->load->model('setting/module');

		$this->load->model('localisation/language');
		$data['languages'] = [];
		$languages = $this->model_localisation_language->getLanguages();

		foreach ($languages as $language){
			if ($language['status']) {
				$data['languages'][] = array(
					'name'  => $language['name'],
					'language_id' => $language['language_id'],
					'code' => $language['code']
				);
			}
		}

		if (isset($this->error['name'])) {
			$data['error_name'] = $this->error['name'];
		} else {
			$data['error_name'] = '';
		}

		$data['heading_title'] = $this->language->get('heading_title');
		$data['text_enabled'] = $this->language->get('text_enabled');
		$data['text_disabled'] = $this->language->get('text_disabled');
		$data['entry_status'] = $this->language->get('entry_status');
		$data['entry_name'] = $this->language->get('entry_name');
		$data['entry_popup'] = $this->language->get('entry_popup');
		
		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		$data['breadcrumbs'] = [];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true)
		];

		if (!isset($this->request->get['module_id'])) {
			$data['breadcrumbs'][] = [
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category', 'user_token=' . $this->session->data['user_token'], true)
			];
		}else{
			$data['breadcrumbs'][] = [
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category', 'user_token=' . $this->session->data['user_token']. '&module_id=' . $this->request->get['module_id'], true)
			];
		}	

		if (!isset($this->request->get['module_id'])) {
			$data['save'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.save', 'user_token=' . $this->session->data['user_token']);
		} else {
			$data['save'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.save', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id']);
		}

		$data['back'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module');
	
		
		if (!isset($this->request->get['module_id'])) {
			$data['action'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category', 'user_token=' . $this->session->data['user_token'], true);
		} else {
			$data['action'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id'], true);
		}

		$data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true);


		if (isset($this->request->get['module_id']) && ($this->request->server['REQUEST_METHOD'] != 'POST')) {
			$module_info = $this->model_setting_module->getModule($this->request->get['module_id']);
		}
		

		if (isset($this->request->post['name'])) {
			$data['name'] = $this->request->post['name'];
		} elseif (!empty($module_info)) {
			$data['name'] = $module_info['name'];
		} else {
			$data['name'] = '';
		}

		$this->load->model('catalog/category');

		$data['categories'] = array();

		if (isset($this->request->post['category'])) {
			$categories = $this->request->post['category'];
		} elseif (!empty($module_info['category'])) {
			$categories = $module_info['category'];
		} else {
			$categories = array();
		}	
		
		foreach ($categories as $category_id) {
			$category_info = $this->model_catalog_category->getCategory($category_id);

			if (!isset($this->request->get['module_id'])) {
				$set_feature_image_link = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.set_feature_image', 'user_token=' . $this->session->data['user_token'] . '&category_id='. $category_id, true);
				$data['feature_image_link_ajax'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.set_feature_image', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id']. '&category_id=', true);
			} else {
				$set_feature_image_link = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.set_feature_image', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id']. '&category_id='. $category_id, true);
			}

			if ($category_info) {
				$data['categories'][] = array(
					'category_id' => $category_info['category_id'],
					'name'        => ($category_info['path']) ? $category_info['path'] . ' &gt; ' . $category_info['name'] : $category_info['name'],
					'set_feature_image_link' => $set_feature_image_link
				);
			}
		}

		if (isset($this->request->post['limit'])) {
			$data['limit'] = $this->request->post['limit'];
		} elseif (!empty($module_info)) {
			$data['limit'] = $module_info['limit'];
		} else {
			$data['limit'] = 5;
		}

		if (!empty($module_info)) {
			$data['view_desc_status'] = $module_info['view_desc_status'];
		} else {
			$data['view_desc_status'] = 0;
		}

		if (!empty($module_info)) {
			$data['char_limit'] = $module_info['char_limit'];
		} else {
			$data['char_limit'] = 50;
		}

		if (isset($this->request->post['width'])) {
			$data['width'] = $this->request->post['width'];
		} elseif (!empty($module_info)) {
			$data['width'] = $module_info['width'];
		} else {
			$data['width'] = 200;
		}

		if (isset($this->request->post['height'])) {
			$data['height'] = $this->request->post['height'];
		} elseif (!empty($module_info)) {
			$data['height'] = $module_info['height'];
		} else {
			$data['height'] = 200;
		}

		if (isset($this->request->post['status'])) {
			$data['status'] = $this->request->post['status'];
		} elseif (!empty($module_info)) {
			$data['status'] = $module_info['status'];
		} else {
			$data['status'] = '';
		}

		$data['user_token'] = $this->session->data['user_token'];
		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/vipodha4featurecategory/module/vipodha_feature_category', $data));

	}	

	public function save(): void {	
		$json = [];		

		$this->load->language('extension/vipodha4featurecategory/module/vipodha_feature_category');
		$this->load->model('extension/vipodha4featurecategory/module/vipodha_feature_category');

		if (!$this->user->hasPermission('modify', 'extension/vipodha4featurecategory/module/vipodha_feature_category')) {
			$json['error'] = $this->language->get('error_permission');
		}
		
		if ((oc_strlen($this->request->post['name']) < 3) || (oc_strlen($this->request->post['name']) > 64)) {
			$json['error']['name'] = $this->language->get('error_name');
		}

		if (!$this->request->post['limit']) {
			$json['error']['limit'] = $this->language->get('error_limit');
		}

		if ($this->request->post['view_desc_status'] == 1) {
			if (!$this->request->post['char_limit']) {
				$json['error']['char-limit'] = $this->language->get('error_char_limit');
			}
		}		

		if (!$this->request->post['width']) {
			$json['error']['width'] = $this->language->get('error_width');
		}

		if (!$this->request->post['height']) {
			$json['error']['height'] = $this->language->get('error_height');
		}

		if (!$json) {
			$this->load->model('setting/module');
			if (!isset($this->request->get['module_id'])) {
				$module_id = $this->model_setting_module->addModule('vipodha4featurecategory.vipodha_feature_category', $this->request->post);
				$json['redirect'] =  $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category', 'user_token=' . $this->session->data['user_token'] . '&module_id='. $module_id, true);
			} else {
				$this->model_setting_module->editModule($this->request->get['module_id'], $this->request->post);
				$json['redirect'] =  $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category', 'user_token=' . $this->session->data['user_token'] . '&module_id='. $this->request->get['module_id'], true);
			}	

			$json['success'] = $this->language->get('text_success');
        }		

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));		
	}

	public function set_feature_image() {
		$this->load->language('extension/vipodha4featurecategory/module/vipodha_feature_category');
		$this->document->setTitle($this->language->get('heading_title'));
		$this->load->model('extension/vipodha4featurecategory/module/vipodha_feature_category');
		$this->getForm();
	}

	private function getForm() {

		$data['breadcrumbs'] = [];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token']. '&type=module', true)
		];

		if (!isset($this->request->get['module_id'])) {
			$data['breadcrumbs'][] = [
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.set_feature_image', 'user_token=' . $this->session->data['user_token'], true)
			];
		} else {
			$data['breadcrumbs'][] =  [
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.set_feature_image', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id'], true)
			];
		}

		if (!isset($this->request->get['module_id'])) {
			$data['back'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category', 'user_token=' . $this->session->data['user_token'], true);
		} else {
			$data['back'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id'], true);
		}

		if (!isset($this->request->get['category_id'])) {
			$data['save_banner'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.save_banner', 'user_token=' . $this->session->data['user_token'], true);
		} else {
			$data['save_banner'] = $this->url->link('extension/vipodha4featurecategory/module/vipodha_feature_category.save_banner', 'user_token=' . $this->session->data['user_token'] . '&category_id=' . $this->request->get['category_id'], true);
		}

		// $this->load->model('catalog/category');
		$this->load->model('tool/image');		

		if (!isset($this->request->get['category_id'])) {
			$category_id = 0;
		}else{
			$category_id = $this->request->get['category_id'];
		}

		$this->load->model('localisation/language');
		$data['languages'] = array();
		$languages_ids = array();
		$languages = $this->model_localisation_language->getLanguages();
		foreach ($languages as $language){
			if ($language['status']) {
				$languages_ids[] =  $language['language_id'];				
			}
		}

		$result = $this->model_extension_vipodha4featurecategory_module_vipodha_feature_category->getVipodhaFeaturecategory($category_id,$languages_ids);

		if ($result[0]['banner'] != "" && is_file(DIR_IMAGE . html_entity_decode($result[0]['banner'], ENT_QUOTES, 'UTF-8')) ) {
			$banner = $this->model_tool_image->resize(html_entity_decode($result[0]['banner'], ENT_QUOTES, 'UTF-8'), 100, 100);
		} else {
			$banner = $this->model_tool_image->resize('no_image.png', 100, 100);
		}	

		$lang_i = 0;
		foreach ($languages as $language){
			if ($language['status']) {
				$languages_ids[] =  $language['language_id'];
				$data['languages'][] = array(
					'name'  => $language['name'],
					'language_id' => $language['language_id'],
					'code' => $language['code'],
					'image' => $language['image'],
					'category_name' => $result[$lang_i]['name']
				);
				$lang_i;
			}
		}
	
		$data['category_id'] = $category_id;
		$data['banner'] = $banner;	

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/vipodha4featurecategory/module/vipodha_feature_category_image', $data));
	}

	public function save_banner(): void {
		$json = [];		

		$this->load->language('extension/vipodha4featurecategory/module/vipodha_feature_category');		
		$this->load->model('extension/vipodha4featurecategory/module/vipodha_feature_category');

		if (!$this->user->hasPermission('modify', 'extension/vipodha4featurecategory/module/vipodha_feature_category')) {
			$json['error'] = $this->language->get('error_permission');
		}

		if (!$this->request->post['category_id']) {
			$json['error']['banner'] = $this->language->get('error_permission');
		}

		if (!$this->request->post['banner']) {
			$json['error']['banner'] = $this->language->get('error_banner');
		}		

		if (!$json) {
			$this->load->model('setting/module');
			if (!isset($this->request->get['module_id'])) {
				$this->model_extension_vipodha4featurecategory_module_vipodha_feature_category->SaveVipodhaFeaturecategory($this->request->post['category_id'], $this->request->post);
				$json['success'] = $this->language->get('text_success');
			}else{
				$json['error'] = $this->language->get('error_permission');
			}
        }

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));	
	}	
}